@@ -22,7 +22,7 @@ The Classes are broken down into categories `Basic`, `Normal`, and `Advanced`
 
 This allows you to run:
 ```rs:no_run
-use crate rpgstat::class::Basic as Class
+use rpgstat::class::Basic as Class
 // more stuff
 fn my_fun () {
     let b = Class::default();
@@ -31,25 +31,9 @@ fn my_fun () {
 ```
 
 # Creatures
- This contains all manner of creatures.  We have `Animal` creatures, `Hero` creatures, and more will come!
+ This contains all manner of creatures.  We have `Animal` creatures, `Hero` creatures, and more to come!
 
 */
 pub mod stats;
 pub mod class;
 pub mod creature;
-
-#[cfg(test)]
-mod tests {
-    use crate::stats::Basic as Stats;
-    use crate::class::Basic as Class;
-    #[test]
-    fn test_basic() {
-        let b:Stats<f64> = Stats::default();
-        assert_eq!(0.0, b.xp);
-    }
-    #[test]
-    fn test_class() {
-        let c:Class = Class::default();
-        assert_eq!(Class::Enemy, c);
-    }
-}
